@@ -105,14 +105,13 @@ Resource::ResourceInfo AccountConfiguration::createPop3Resource() const
     Resource::ResourceInfo info;
     info.typeIdentifier = u"akonadi_pop3_resource"_s;
     info.name = generateUniqueAccountName();
-    QMap<QString, QVariant> settings;
-    settings.insert(u"Port"_s, mIncomingPort);
-    settings.insert(u"Host"_s, mIncomingHostName);
-    settings.insert(u"Login"_s, mIncomingUserName);
-    settings.insert(u"Password"_s, mPassword);
-    settings.insert(u"UseTLS"_s, true);
-
-    info.settings = settings;
+    info.settings = {
+        {u"Port"_s, mIncomingPort},
+        {u"Host"_s, mIncomingHostName},
+        {u"Login"_s, mIncomingUserName},
+        {u"Password"_s, mPassword},
+        {u"UseTLS"_s, true},
+    };
     return info;
 }
 
@@ -121,39 +120,62 @@ Resource::ResourceInfo AccountConfiguration::createImapResource() const
     Resource::ResourceInfo info;
     info.typeIdentifier = u"akonadi_imap_resource"_s;
     info.name = generateUniqueAccountName();
-    QMap<QString, QVariant> settings;
-    settings.insert(u"ImapServer"_s, mIncomingHostName);
-    settings.insert(u"UserName"_s, mIncomingUserName);
-    settings.insert(u"DisconnectedModeEnabled"_s, mDisconnectedModeEnabled);
-    settings.insert(u"Password"_s, mPassword);
-    settings.insert(u"ImapPort"_s, mIncomingPort);
-    settings.insert(u"IntervalCheckTime"_s, 60);
-    settings.insert(u"SubscriptionEnabled"_s, true);
-    settings.insert(u"UseDefaultIdentity"_s, false);
-    settings.insert(u"AccountIdentity"_s, mIdentity.uoid());
-    settings.insert(u"Authentication"_s, mIncomingAuthenticationProtocol);
-    settings.insert(u"Safety"_s, mIncomingSecurityProtocol);
-    info.settings = settings;
+    info.settings = {
+        {u"ImapServer"_s, mIncomingHostName},
+        {u"UserName"_s, mIncomingUserName},
+        {u"DisconnectedModeEnabled"_s, mDisconnectedModeEnabled},
+        {u"Password"_s, mPassword},
+        {u"ImapPort"_s, mIncomingPort},
+        {u"IntervalCheckTime"_s, 60},
+        {u"SubscriptionEnabled"_s, true},
+        {u"UseDefaultIdentity"_s, false},
+        {u"AccountIdentity"_s, mIdentity.uoid()},
+        {u"Authentication"_s, mIncomingAuthenticationProtocol},
+    };
+
+    switch (mIncomingSecurityProtocol) {
+    case MailTransport::Transport::EnumEncryption::None:
+        info.settings[u"Safety"_s] = QStringLiteral("None");
+        break;
+    case MailTransport::Transport::EnumEncryption::SSL:
+        info.settings[u"Safety"_s] = QStringLiteral("SSL");
+        break;
+    case MailTransport::Transport::EnumEncryption::TLS:
+        info.settings[u"Safety"_s] = QStringLiteral("STARTTLS");
+        break;
+    }
+    return info;
+}
+
+Resource::ResourceInfo AccountConfiguration::createGmailResource() const
+{
+    Resource::ResourceInfo info;
+    info.typeIdentifier = u"akonadi_google_resource"_s;
+    info.name = u"Google (%1)"_s.arg(mIdentity.primaryEmailAddress());
+    info.settings = {
+        {u"Account"_s, mIdentity.primaryEmailAddress()},
+    };
     return info;
 }
 
 Resource::ResourceInfo AccountConfiguration::createKolabResource() const
 {
-    Resource::ResourceInfo info;
+    auto info = createImapResource();
     info.name = generateUniqueAccountName();
-    QMap<QString, QVariant> settings;
-    settings.insert(u"ImapServer"_s, mIncomingHostName);
-    settings.insert(u"UserName"_s, mIncomingUserName);
-    settings.insert(u"DisconnectedModeEnabled"_s, true);
-    settings.insert(u"AccountIdentity"_s, mIdentity.uoid());
-    settings.insert(u"UseDefaultIdentity"_s, false);
-    settings.insert(u"SieveSupport"_s, true);
-    settings.insert(u"IntervalCheckTime"_s, 60);
-    settings.insert(u"SubscriptionEnabled"_s, true);
-    settings.insert(u"Password"_s, mPassword);
-    settings.insert(u"ImapPort"_s, mIncomingPort);
-    info.settings = settings;
     info.typeIdentifier = u"akonadi_kolab_resource"_s;
+    info.settings = {
+        {u"ImapServer"_s, mIncomingHostName},
+        {u"UserName"_s, mIncomingUserName},
+        {u"DisconnectedModeEnabled"_s, mDisconnectedModeEnabled},
+        {u"Password"_s, mPassword},
+        {u"ImapPort"_s, mIncomingPort},
+        {u"IntervalCheckTime"_s, 60},
+        {u"SubscriptionEnabled"_s, true},
+        {u"UseDefaultIdentity"_s, false},
+        {u"AccountIdentity"_s, mIdentity.uoid()},
+        {u"Authentication"_s, mIncomingAuthenticationProtocol},
+        {u"Safety"_s, mIncomingSecurityProtocol},
+    };
     return info;
 }
 
@@ -230,6 +252,7 @@ void AccountConfiguration::save(ConsoleLog *consoleLog)
     if (mHasTransport) {
         // create transport
         using TransportAuth = MailTransport::Transport::EnumAuthenticationType;
+        mMailTransport->save();
         MailTransport::TransportManager::self()->addTransport(mMailTransport);
 
         QString logEntryText = u"<h3>"_s + i18nc("log entry content", "Mail transport setup completed: %1", mMailTransport->name()) + u"</h3>"_s;
@@ -249,6 +272,12 @@ void AccountConfiguration::save(ConsoleLog *consoleLog)
         mIdentity.setTransport(QString::number(mMailTransport->id()));
     }
 
+    if (mGroupware) {
+        if (std::holds_alternative<GMailGroupware>(mGroupware.value())) {
+            Resource::ResourceInfo info = createGmailResource();
+            generateResource(std::move(info), consoleLog);
+        }
+    }
     mIdentityManager->saveIdentity(mIdentity);
 }
 
@@ -507,6 +536,20 @@ void AccountConfiguration::setHasTransport(bool hasTransport)
     mHasTransport = hasTransport;
 }
 
+std::optional<GroupwareServer> AccountConfiguration::groupware() const
+{
+    return mGroupware;
+}
+
+void AccountConfiguration::setGroupware(std::optional<GroupwareServer> groupware)
+{
+    if (groupware) {
+        if (std::holds_alternative<GMailGroupware>(groupware.value())) {
+            mGroupware = std::get<GMailGroupware>(groupware.value());
+        }
+    }
+}
+
 QDebug operator<<(QDebug d, const AccountConfiguration &t)
 {
     d.space() << "mIncomingUserName" << t.incomingUserName();
